@@ -1,7 +1,9 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright 2013-2022 Fraunhofer FKIE
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -12,7 +14,7 @@
 #  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-#  * Neither the name of the Fraunhofer organization nor the names of its
+#  * Neither the name of the copyright holder nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
 #
@@ -120,6 +122,8 @@ def targets(linter):
     linter.add_command_hook("set_target_properties", on_set_target_properties)
     linter.add_command_hook("add_executable", on_add_target)
     linter.add_command_hook("add_library", on_add_target)
+    linter.add_command_hook("pybind_add_module", on_add_target)
+    linter.add_command_hook("pybind11_add_module", on_add_target)
     linter.add_command_hook("target_link_libraries", on_target_link_libraries)
     linter.add_final_hook(on_final)
 
