@@ -1,7 +1,9 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright 2013-2022 Fraunhofer FKIE
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -12,7 +14,7 @@
 #  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-#  * Neither the name of the Fraunhofer organization nor the names of its
+#  * Neither the name of the copyright holder nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
 #
@@ -247,9 +249,12 @@ class LintInfo(object):
         return self.is_catkin_install_destination(path, "bin") or self.is_catkin_install_destination(path, "lib/%s" % self.manifest.name)
 
     def condition_is_checked(self, expr):
+        not_expr = "NOT " + expr if expr[:4] != "NOT " else expr[4:]
         for c in self.conditionals:
             if expr in c.expr and c.value:
                 return True
+            if not_expr in c.expr and not c.value:
+                return True
         return False
 
 
@@ -257,6 +262,7 @@ class IfCondition(object):
     def __init__(self, expr, value):
         self.expr = expr
         self.value = value
+        self.depth = 1
 
 
 class CMakeLinter(object):
@@ -467,8 +473,12 @@ class CMakeLinter(object):
     def _handle_if(self, info, cmd, args, arg_tokens):
         def is_string_comparison_op(x):
             return x in ["MATCHES", "IS_NEWER_THAN", "STRLESS", "STRGREATER", "STREQUAL", "STRLESS_EQUAL", "STRGREATER_EQUAL", "VERSION_LESS", "VERSION_GREATER", "VERSION_EQUAL", "VERSION_LESS_EQUAL", "VERSION_GREATER_EQUAL"]
-        if cmd == "if":
+        if cmd == "if" or cmd == "elseif":
             info.conditionals.append(IfCondition(" ".join(args), True))
+            if cmd == "elseif" and len(info.conditionals) > 1:
+                # Keep track of the number of conditions that go out of scope with the endif()
+                info.conditionals[-1].depth += info.conditionals[-2].depth
+                info.conditionals[-2].value = False
             if len(arg_tokens) == 1 and arg_tokens[0][0] == "WORD" and re.match(r"\${[a-z_0-9]+}$", arg_tokens[0][1], re.IGNORECASE):
                 info.report(WARNING, "AMBIGUOUS_CONDITION", cond=arg_tokens[0][1])
             for i, tok in enumerate(arg_tokens):
@@ -488,8 +498,9 @@ class CMakeLinter(object):
             if len(info.conditionals) > 0:
                 info.conditionals[-1].value = False
         if cmd == "endif":
-            if len(info.conditionals) > 0:
-                info.conditionals.pop()
+            depth = min(info.conditionals[-1].depth, len(info.conditionals))
+            if depth > 0:
+                del info.conditionals[-depth:]
 
     def _handle_find_package(self, module, info):
         SPECIAL_CASES = {"yaml-cpp": "YAML_CPP"}
@@ -609,9 +620,9 @@ class CMakeLinter(object):
                 if depth < cur_depth:
                     del cur_col[depth + 1:]
                     cur_depth = depth
-                if cmd == "else":
+                if cmd == "else" or cmd == "elseif":
                     if len(cur_col[-1]) < 2:
-                        raise CMakeSyntaxError("%s(%d): else() without if()" % (info.file, info.line))
+                        raise CMakeSyntaxError("%s(%d): %s() without if()" % (info.file, info.line, cmd))
                     if column != cur_col[-1][-2]:
                         info.report(NOTICE, "INDENTATION")
                     cur_col[-1][-1] = None
@@ -630,7 +641,7 @@ class CMakeLinter(object):
                         info.report(NOTICE, "INDENTATION")
                 if cmd in ["if", "foreach"]:
                     cur_col[-1].append(None)
-                if cmd in ["if", "else", "endif"]:
+                if cmd in ["if", "else", "elseif", "endif"]:
                     self._handle_if(info, cmd, args, arg_tokens)
                 if cmd == "project" and info.subdir:
                     info.report(WARNING, "SUBPROJECT", subdir=info.subdir)
