@@ -1,7 +1,9 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2020 Fraunhofer FKIE
+# Copyright 2013-2022 Fraunhofer FKIE
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -12,7 +14,7 @@
 #  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-#  * Neither the name of the Fraunhofer organization nor the names of its
+#  * Neither the name of the copyright holder nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
 #
@@ -190,6 +192,8 @@ class LinterTest(unittest.TestCase):
         self.assertEqual(["UNQUOTED_STRING_OP"], result)
         self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "else()")
         self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "endif()")
+        self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "elseif(TRUE)")
+        self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "if(FALSE) elseif(STREQUAL) endif()")
         self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "if(STREQUAL) endif()")
         self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "if(A STREQUAL) endif()")
         self.assertRaises(CMakeSyntaxError, mock_lint, env, pkg, "if(STREQUAL A) endif()")
